#ifndef TP_COS_H
#define TP_COS_H

/*************
 *
 *    Flags are boolean valued options.  To install a new flag, append
 *    a new name and index to the end of this list, then insert code to
 *    initialize it in the routine `init_options'.
 *    Example access:  if (Flags[PARA_FROM_LEFT].val) { ... }
 *    See routine `init_options' for defaults.
 *
 *************/

#define MAX_FLAGS          100  /* increase if necessary */

#define DISPLAY_TERMS        0  /* print terms in internal format */
#define CHECK_ARITY          1  /* check if equal symbols have equal arities */
#define PROLOG_STYLE_VARIABLES 2
#define PRINT_GEN            4
#define DEMOD_HISTORY        6
#define INDEX_DEMOD          8
#define INDEX_AC_ARGS        9
#define PRINT_GIVEN         10
#define ALPHA_PAIR_WEIGHT   12
#define CHECK_INPUT_DEMODULATORS   13
#define INPUT_CONFLICT_CHECK       14
#define LRPO                15
#define PARA_PAIRS          16
#define PRINT_FORWARD_SUBSUMED  17
#define PRINT_BACK_DEMOD  	18
#define PRINT_LISTS_AT_END  	19

/* end of Flags */

/*************
 *
 *    Parms are integer valued options.  To install a new parm, append
 *    a new name and index to this list, then insert code to
 *    initialize it in the routine `init_options'.
 *    Example access:  if (Parms[FPA_LITERALS].val == 4) { ... }
 *    See routine `init_options' for defaults.
 *
 *************/

#define MAX_PARMS        30  /* increase if necessary */

#define MAX_MEM           0  /* stop search after this many K bytes allocated */
#define MAX_WEIGHT        1
#define MAX_GIVEN         2
#define WEIGHT_FUNCTION   3
#define MAX_PAIR_WEIGHT   4  /* For paramodulation-by-pairs. */
#define MAX_PROOFS        5
#define REPORT_GIVEN      6
#define AC_SUPERSET_LIMIT 8
#define MAX_SECONDS       9

/* end of Parms */

/*************
 *
 *    Statistics.  To install a new statistic, append a new name and
 *    index to this list, then insert the code to output it in the
 *    routine `print_stats'.
 *    Example access:  Stats[INPUT_ERRORS]++;
 *
 *************/

#define MAX_STATS        40  /* increase if necessary */

#define BT_OCCUR_CHECKS   0
#define REWRITES          1
#define FPA_OVERLOADS     2
#define FPA_UNDERLOADS    3
#define AC_INITIATIONS    4
#define AC_CONTINUATIONS  5
#define REWRITE_ATTEMPTS  6

#define INIT_WALL_SECONDS         7
#define INPUT_ERRORS              8
#define K_MALLOCED                9

#define CLAUSES_INPUT                  10
#define CLAUSES_GENERATED_INPUT        11
#define CLAUSES_FORWARD_SUBSUMED_INPUT 12
#define CLAUSES_KEPT_INPUT             13
#define NEW_DEMODULATORS_INPUT         14
#define CLAUSES_BACK_DEMODULATED_INPUT 15

#define GIVEN                    16
#define CLAUSES_GENERATED        17
#define CLAUSES_WT_DELETE        18
#define CLAUSES_FORWARD_SUBSUMED 19
#define CLAUSES_KEPT             20
#define NEW_DEMODULATORS         21
#define CLAUSES_BACK_DEMODULATED 22

#define PROOFS                   23

#define SOS_SIZE                 24
#define USABLE_SIZE              25
#define DEMODULATORS_SIZE        26
#define PASSIVE_SIZE             27
#define DELETED_CLAUSES_SIZE     28

#define PAIRS_PENDING            29
#define GREATEST_PAIR_USED       30
#define GREATEST_PAIR            31

#define USABLE_INPUT             32
#define SOS_INPUT                33
#define DEMODULATORS_INPUT       34
#define PASSIVE_INPUT            35

/* end of Stats */

/*************
 *
 *    Clocks.  To install a new clock, append a new name and
 *    index to this list, then insert the code to output it in the
 *    routine `print_times'.  Example of use: CLOCK_START(INPUT_TIME),
 *    CLOCK_STOP(INPUT_TIME),  micro_sec = clock_val(INPUT_TIME);.
 *    See files macros.h and clocks.c.
 *
 *************/

#define MAX_CLOCKS          40
 
#define RUN_TIME             1
#define INPUT_TIME           0

#define PARAMOD_TIME         2
#define FOR_SUB_TIME         3
#define DEMOD_TIME           4
#define BD_FIND_TIME         5
#define CONFLICT_TIME        6
#define LRPO_TIME            7
#define WEIGH_TIME           8
#define ORIENT_EQ_TIME       9

/* end of Clocks */

#endif  /* ! TP_COS_H */
